@@ -31,7 +31,7 @@ class ApiProvider:
         self.retries = retries
 
         # NOTE: do not change this, due to crypto.com rate-limit 10-per second
-        self.semaphore = asyncio.Semaphore(5)
+        self.semaphore = asyncio.Semaphore(10)
 
         if not auth_required:
             return
@@ -113,6 +113,9 @@ class ApiProvider:
                 await asyncio.sleep(1)
                 continue
             except ContentTypeError:
+                if resp.status == 429:
+                    await asyncio.sleep(1)
+                    continue
                 text = await resp.text()
                 raise ApiError(
                     f"Can't decode json, content: {text}. "
